package com.example

import org.rocksdb.Options
import org.rocksdb.RocksDB
import org.rocksdb.RocksIterator

fun main() {
    RocksDB.loadLibrary()

    val options = Options().setCreateIfMissing(true)
    val dbPath = "data/rocksdb" 

    try {
        RocksDB.open(options, dbPath).use { db ->
            val iterator: RocksIterator = db.newIterator()
            iterator.seekToFirst()

            while (iterator.isValid) {
                val key = String(iterator.key(), Charsets.UTF_8)
                val value = String(iterator.value(), Charsets.UTF_8)
                val tokens = value.split("::")
                val accessToken = tokens.getOrNull(0)
                val refreshToken = tokens.getOrNull(1)
                println("Key (ID Token): $key")
                println("Access Token: $accessToken")
                println("Refresh Token: $refreshToken")
                iterator.next()
            }
        }
    } catch (e: Exception) {
        e.printStackTrace()
    } finally {
        options.close()
    }
}