package com.example.firebaseauth

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.lifecycle.viewmodel.compose.viewModel
import androidx.navigation.compose.rememberNavController
import com.example.firebaseauth.auth.AuthRepository
import com.example.firebaseauth.auth.AuthState
import com.example.firebaseauth.auth.AuthViewModel
import com.example.firebaseauth.auth.AuthViewModelFactory
import com.example.firebaseauth.navigation.NavGraph
import com.example.firebaseauth.ui.theme.FireBaseAuthTheme

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        setContent {
            FireBaseAuthTheme {
                val authViewModel: AuthViewModel = viewModel(factory = AuthViewModelFactory(AuthRepository()))
                val navController = rememberNavController()
                val authState by authViewModel.authState.collectAsState() // current authentication state

                val startDestination = when (authState) {
                    is AuthState.Authenticated -> "main" //authenticated user
                    else -> "auth" // user still needs to authenticate
                }

                NavGraph(navController = navController, authViewModel = authViewModel, startDestination = startDestination)
            }
        }
    }
}
