package com.example.firebaseauth.auth

import com.google.firebase.auth.FirebaseAuth
import com.google.firebase.auth.FirebaseUser
import com.google.firebase.auth.GoogleAuthProvider
import kotlinx.coroutines.tasks.await


//  Repository class for handling Firebase authentication
class AuthRepository {
    private val auth: FirebaseAuth = FirebaseAuth.getInstance()

    // Sign in a user given its Google ID token
    // Returns the authenticated FirebaseUser if successfully authenticated
    // From https://firebase.google.com/docs/auth/android/google-signin
    suspend fun signInWithGoogle(idToken: String): Result<FirebaseUser> {
        return try {
            val credential = GoogleAuthProvider.getCredential(idToken, null)
            val authResult = auth.signInWithCredential(credential).await()
            Result.success(authResult.user!!)
        } catch (e: Exception) {
            Result.failure(e)
        }
    }

    // Sign out the authenticated user
    fun signOut() {
        auth.signOut()
    }

    // Retrieve the signed-in user, or null if no user is signed in
    fun getCurrentUser() = auth.currentUser
}