package com.example.firebaseauth.auth

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.launch

// for managing authentication state
class AuthViewModel(private val authRepository: AuthRepository) : ViewModel() {

    private val _authState = MutableStateFlow<AuthState>(AuthState.Loading)
    val authState: StateFlow<AuthState> = _authState

    init {
        // Initialize the authentication state based on the current user
        val currentUser = authRepository.getCurrentUser()
        if (currentUser != null) {
            _authState.value = AuthState.Authenticated(currentUser)
        } else {
            _authState.value = AuthState.Unauthenticated
        }
    }

    // Attempts to sign in with a Google account using the provided ID token
    fun signInWithGoogle(idToken: String) {
        viewModelScope.launch {
            _authState.value = AuthState.Loading
            val result = authRepository.signInWithGoogle(idToken)
            if (result.isSuccess) {
                _authState.value = AuthState.Authenticated(result.getOrNull()!!)
            } else {
                _authState.value = AuthState.Unauthenticated
            }
        }
    }

    // Signs out the current user
    fun signOut() {
        authRepository.signOut()
        _authState.value = AuthState.Unauthenticated
    }
}