package com.example.firebaseauth.utils


import android.annotation.SuppressLint
import android.os.Build
import android.util.Log
import androidx.annotation.RequiresApi
import com.google.firebase.messaging.FirebaseMessagingService
import com.google.firebase.messaging.RemoteMessage
import java.io.IOException
import java.security.MessageDigest
import java.util.Base64

@SuppressLint("MissingFirebaseInstanceTokenRefresh") // for warnings
class MyFirebaseMessagingService : FirebaseMessagingService() {

    @RequiresApi(Build.VERSION_CODES.O)
    // Called when a Firebase Cloud Messaging (FCM) message is received
    override fun onMessageReceived(remoteMessage: RemoteMessage) {
        super.onMessageReceived(remoteMessage)

        // Log the received message
        Log.d("FCM", "Message received from: ${remoteMessage.from}")

        // Check for data payload
        remoteMessage.data.let { data ->
            if (data.isNotEmpty()) {
                Log.d("FCM", "Message data payload: $data")

                // Only message sent should be when access token is refreshed
                // id token needed to request the new passpoint profile
                val accessToken = data["accessToken"]
                val subidToken = data["idToken"]

                if (accessToken != null) {
                    // After successful authentication, create Android profile request
                    // hashed access token otherwise would be too long as pwd
                    val hashedAccessToken = Base64.getEncoder().encodeToString(MessageDigest.getInstance("SHA-256").digest(accessToken.toByteArray()))
                    val profileRequest = subidToken?.let {
                        AndroidProfileRequest(
                            friendlyName = "OpenRoaming network (e-ID)",
                            username = subidToken,
                            password = hashedAccessToken)
                    }
                    // Send the profile request to the server

                    if (profileRequest != null) {
                        sendGenerateAndroidProfileRequest(applicationContext, profileRequest)
                    } else {
                        Log.e("FMS", "Failed to build profile")
                    }
                } else {
                    throw IOException("Failed to retrieve tokens")
                }
            } else {
                Log.e("FMS", "Failed to update profile")

            }
        }

        // Check for notification payload
        remoteMessage.notification?.let { notification ->
            Log.d("FCM", "Message Notification Body: ${notification.body}")
        }
    }
}
